<?php
/**
 * @package			No Boss Extensions
 * @subpackage  	Template padrao
 * @author			No Boss Technology <contact@nobosstechnology.com>
 * @copyright		Copyright (C) 2021 No Boss Technology. All rights reserved.
 * @license			GNU Lesser General Public License version 3 or later; see <https://www.gnu.org/licenses/lgpl-3.0.en.html>
 */

defined('_JEXEC') or die;
$app = JFactory::getApplication();
$doc = JFactory::getDocument();

$templateParams = $app->getTemplate(true)->params;

// carrega o helper do template
JLoader::register('NoBossNemesisTemplateHelper', __DIR__ . '/helper.php');
$params = NoBossNemesisTemplateHelper::getTemplateParams($templateParams);

?>

<!DOCTYPE html>
<html xmlns="http://www.w3.org/1999/xhtml" xml:lang="<?php echo $this->language; ?>" lang="<?php echo $this->language; ?>" dir="<?php echo $this->direction; ?>">

<head>
	<meta charset="UTF-8">
	<meta name="viewport" content="width=device-width, initial-scale=1">
	<link rel="stylesheet" href="<?php echo $this->baseurl; ?>/templates/<?php echo $this->template; ?>/assets/stylesheets/css/style.min.css" type="text/css" />

	<?php // Adiciona suporte quando acesso for utilizando touch (mobile/tela touch) ?>
	<script> 
	document.documentElement.className += "ontouchstart" in document.documentElement ? " touch" : " no-touch";
	document.documentElement.className = document.documentElement.className.replace("no-js","js");
	var baseNameUrl = "<?php echo JUri::root(); ?>";
	</script>

	<title><?php echo $this->error->getCode(); ?> - <?php echo htmlspecialchars($this->error->getMessage(), ENT_QUOTES, 'UTF-8'); ?></title>
    <?php // verifica se o custom.css deve ser carregado ?>
    <?php 
    // Carregar arquivo customizado de CSS do template
    if(($params->customization->load_custom_css) && (JFile::exists(JPATH_ROOT . '/templates/nobossnemesis/assets/stylesheets/css/custom.css'))){
        $doc->addStyleSheet($this->baseurl . '/templates/nobossnemesis/assets/stylesheets/css/custom.css');
    } 
    ?>
	<style type="text/css">
        :root{
            <?php echo $params->customization->variablesCss; ?>
        }
    </style>
</head>
	<body class="error_page nobossnemesis">
		<?php
		// Carrega o header caso uma posicao de modulo tenha sido definida
		if(!empty($params->layout->headerPosition)){
			echo JHTML::_('content.prepare', '{loadposition '.$params->layout->headerPosition.', none }');
		}
		// Fixa uma posicao como alternativa
		else{
			echo JHTML::_('content.prepare', '{loadposition nobossheader, none }');
		}
		?>
	
		<main role="main">
			<div class="error_page-content">
				<?php $texto = JHTML::_('content.prepare', '{loadposition error_page, none }');

				$texto =  str_replace ('##URL##', JUri::current(), $texto);
				echo str_replace ('##HOME_URL##', JURI::base(), $texto);
				?>
			</div>
		</main>

		<?php
		// carrega o footer caso uma posicao de modulo tenha sido definida
		if(!empty($params->layout->footerPosition)){
			echo JHTML::_('content.prepare', '{loadposition '.$params->layout->footerPosition.', none }');
		}
		// Fixa uma posicao como alternativa
		else{
			echo JHTML::_('content.prepare', '{loadposition nobossfooter, none }');
		}

		$doc->addScript($this->baseurl . '/libraries/noboss/assets/util/js/min/cssvarpolyfill.min.js', array('version' => 'auto', 'relative' => false), array('async' => true, 'defer' => true));
		?>
	</body>
	<?php 
        
    jimport('noboss.util.loadextensionassets');
    
    // Executa funcao para adicionar arquivos e inline (soh retorna html $addViaJs for false)
    $html = NoBossUtilLoadExtensionAssets::addCss();  

    // Executa funcao para adicionar arquivos e inline (soh retorna html $addViaJs for false)
    $html .= NoBossUtilLoadExtensionAssets::addJs();  

    echo $html;
	
	?>
</html>
