<?php
/**
 * @package         No Boss Extensions
 * @subpackage      Template padrao
 * @author          No Boss Technology <contact@nobosstechnology.com>
 * @copyright       Copyright (C) 2021 No Boss Technology. All rights reserved.
 * @license         GNU Lesser General Public License version 3 or later; see <https://www.gnu.org/licenses/lgpl-3.0.en.html>
 */
defined ( '_JEXEC' ) or die ();
jimport('noboss.util.fonts');

class NoBossNemesisTemplateHelper{

    /**
	 * Prepara as configuracoes setadas no admin do template para serem aplicadas como estilo CSS
	 *
	 * @param 	object 	$tmplParams objeto com os valores setados para cada parametro do admin
	 *
	 * @return StdClass objeto com os parametros ja tratados
	 */
    public static function getTemplateParams($tmplParams){
        // Necessario armazenar os parametros em variaveis para manter compatibilidade com alguns servidores
        $primaryColor = $tmplParams->get('primary_color');
        $secondaryColor = $tmplParams->get('secondary_color');
        $bodyColor = $tmplParams->get('body_color');
        $textsColor = $tmplParams->get('texts_color');
        $listsColor = $tmplParams->get('lists_color');
        $linksColor = $tmplParams->get('links_color');
        $linksColorHover = $tmplParams->get('links_color_hover');
        $textsSize = $tmplParams->get('texts_size');
        $textsSizeMobile = $tmplParams->get('texts_size_mobile');
        $listsFontSize = $tmplParams->get('lists_font_size');
        $listsFontSizeMobile = $tmplParams->get('lists_font_size_mobile');

        // objeto que guardara toda a configuracao feita no admin do template
        $params = new StdClass;
        // configuracao da aba de personalizacao
        $params->customization = new StdClass;
        // cor primaria
        $params->customization->primaryColor = !empty($primaryColor) ? "--nb-primary-color: {$primaryColor};" : "";
        $params->customization->secondaryColor = !empty($secondaryColor) ? "--nb-secondary-color: {$secondaryColor};" : "";
        // personalizacoes para o body
        $params->customization->bodyBackgroundColor = "--nb-body-bg-color: {$tmplParams->get('background_color')};";
        $params->customization->bodyFont = "--nb-body-font-family: " . NoBossUtilFonts::importNobossfontlist($tmplParams->get('body_font'), true) . ";";
        $params->customization->bodyFontSize = "--nb-body-font-size: {$tmplParams->get('body_font_size')}px;";
        $params->customization->bodyLineHeight = "--nb-body-line-height: {$tmplParams->get('body_line_height')};";
        $params->customization->bodyTextColor = !empty($bodyColor) ? "--nb-body-font-color: {$bodyColor};" : "";
        // array com as variaveis dos parametros do body
        $bodyParams = array($params->customization->primaryColor, $params->customization->secondaryColor, $params->customization->bodyBackgroundColor,$params->customization->bodyFont, $params->customization->bodyFontSize, $params->customization->bodyLineHeight, $params->customization->bodyTextColor);
        // junta todos os valores dos parametros do body em uma string
        $params->customization->variablesCss = implode("\n", $bodyParams);
        // personalizacoes para os textos
        $params->customization->textsFont = "--nb-texts-font-family: " . NoBossUtilFonts::importNobossfontlist($tmplParams->get('texts_font'), true) . ";";
        $params->customization->textsSize = "";
        if(!empty($textsSize)){
            $fontSizeEm = $textsSize / 16;
            $params->customization->textsSize = "--nb-texts-font-size: {$textsSize}px;" . "\n" . "--nb-texts-font-size-em: {$fontSizeEm}em;";
        }
        $params->customization->textsSizeMobile = "";
        if(!empty($textsSizeMobile)){
            $fontSizeEm = $textsSizeMobile / 16;
            $params->customization->textsSizeMobile = "--nb-mobile-texts-font-size: {$textsSizeMobile}px;" . "\n" . "--nb-mobile-texts-font-size-em: {$fontSizeEm}em;";
        }

        $params->customization->textsColor = !empty($textsColor) ? "--nb-texts-font-color: {$textsColor};" : "";
        $params->customization->textsSpace = "--nb-texts-padding: " . implode(" ", $tmplParams->get('texts_space')) . ";";
        // array com as variaveis dos parametros dos textos
        $textsParams = array($params->customization->textsFont, $params->customization->textsSize, $params->customization->textsColor, $params->customization->textsSpace, $params->customization->textsSizeMobile);
        // junta todos os valores dos parametros dos textos em uma string
        $params->customization->variablesCss .= "\n";
        $params->customization->variablesCss .= implode("\n", $textsParams);
        // personalizacoes para listas
        $params->customization->listsFont = "--nb-lists-font-family: ". NoBossUtilFonts::importNobossfontlist($tmplParams->get('lists_font'), true) . ";";
        $params->customization->listsSize = "";
        if(!empty($listsFontSize)){
            $fontSizeEm = $listsFontSize / 16;
            $params->customization->listsSize = "--nb-lists-font-size: {$listsFontSize}px;" . "\n" . "--nb-lists-font-size-em: {$fontSizeEm}em;";
        }
        $params->customization->listsSizeMobile = "";
        if(!empty($listsFontSizeMobile)){
            $fontSizeEm = $listsFontSizeMobile / 16;
            $params->customization->listsSizeMobile = "--nb-mobile-lists-font-size: {$listsFontSizeMobile}px;" . "\n" . "--nb-mobile-lists-font-size-em: {$fontSizeEm}em;";
        }
        $params->customization->listsColor = !empty($listsColor) ? "--nb-lists-font-color: {$listsColor};" : "";
        $params->customization->listsSpace = "--nb-lists-font-padding: " . implode(" ", $tmplParams->get('lists_space')) . ";";
        // array com as variaveis dos parametros das listas
        $listsParams = array($params->customization->listsFont, $params->customization->listsSize, $params->customization->listsColor, $params->customization->listsSpace, $params->customization->listsSizeMobile);
        // junta todos os valores dos parametros das listas em uma string
        $params->customization->variablesCss .= "\n";
        $params->customization->variablesCss .= implode("\n", $listsParams);

        // personalizacoes para links
        $params->customization->linksEnableUnderline = $tmplParams->get('enable_underline') ? "--nb-links-decoration: underline;" : "--nb-links-decoration: none;";
        $params->customization->linksColor = !empty($linksColor) ? "--nb-links-color: {$linksColor};" : "";
        $params->customization->linksColorHover = !empty($linksColorHover) ? "--nb-links-color-hover: {$linksColorHover};" : "";
        
        // array com as variaveis dos parametros das listas
        $linksParams = array($params->customization->linksEnableUnderline, $params->customization->linksColor, $params->customization->linksColorHover);
        
        // junta todos os valores dos parametros das listas em uma string
        $params->customization->variablesCss .= "\n";
        $params->customization->variablesCss .= implode("\n", $linksParams);
 
        // personalizacoes para tags de heading
        // pega o estilo setado na modal do h1
        $h1Style = json_decode($tmplParams->get('heading_h1'));
        if(!empty($h1Style)){
            // atribui esses valores para o objeto de configuracoes
            $params->customization->h1 = new StdClass;
            $params->customization->h1->font = "--nb-h1-font-family: ". NoBossUtilFonts::importNobossfontlist($h1Style->title_font, true) . ";";
            $params->customization->h1->alignment = "--nb-h1-align: {$h1Style->title_alignment};";
            $params->customization->h1->transform = "--nb-h1-transform: {$h1Style->title_transform};";
            $params->customization->h1->size = "";
            if(!empty($h1Style->title_size)){
                $fontSizeEm = $h1Style->title_size / 16;
                $params->customization->h1->size = "--nb-h1-font-size: {$h1Style->title_size}px;" . "\n" . "--nb-h1-font-size-em: {$fontSizeEm}em;";
            }
            $params->customization->h1->sizeMobile = "";
            if(!empty($h1Style->title_size_mobile)){
                $fontSizeEm = $h1Style->title_size_mobile / 16;
                $params->customization->h1->sizeMobile = "--nb-mobile-h1-font-size: {$h1Style->title_size_mobile}px;" . "\n" . "--nb-mobile-h1-font-size-em: {$fontSizeEm}em;";
            }
            $params->customization->h1->color = !empty($h1Style->title_color) ? "--nb-h1-color: {$h1Style->title_color};" : "";
            $params->customization->h1->space = "--nb-h1-padding: " . implode(" ", $h1Style->title_space) . ";";
            // array com as variaveis dos parametros para h1
            $h1Params = array($params->customization->h1->font, $params->customization->h1->alignment, $params->customization->h1->transform, $params->customization->h1->size, $params->customization->h1->color, $params->customization->h1->space, $params->customization->h1->sizeMobile);
            // junta todos os valores dos parametros dos textos em uma string
            $params->customization->variablesCss .= "\n";
            $params->customization->variablesCss .= implode("\n", $h1Params);

        }
        // pega o estilo setado na modal do h2
        $h2Style = json_decode($tmplParams->get('heading_h2'));
        if(!empty($h2Style)){
            // atribui esses valores para o objeto de configuracoes
            $params->customization->h2 = new StdClass;
            $params->customization->h2->font = "--nb-h2-font-family: " . NoBossUtilFonts::importNobossfontlist($h2Style->title_font, true) . ";";
            $params->customization->h2->alignment = "--nb-h2-align: {$h2Style->title_alignment};";
            $params->customization->h2->transform = "--nb-h2-transform: {$h2Style->title_transform};";
            $params->customization->h2->size = "";
            if(!empty($h2Style->title_size)){
                $fontSizeEm = $h2Style->title_size / 16;
                $params->customization->h2->size = "--nb-h2-font-size: {$h2Style->title_size}px;" . "\n" . "--nb-h2-font-size-em: {$fontSizeEm}em;";
            }
            $params->customization->h2->sizeMobile = "";
            if(!empty($h2Style->title_size_mobile)){
                $fontSizeEm = $h2Style->title_size_mobile / 16;
                $params->customization->h2->sizeMobile = "--nb-mobile-h2-font-size: {$h2Style->title_size_mobile}px;" . "\n" . "--nb-mobile-h2-font-size-em: {$fontSizeEm}em;";
            }
            $params->customization->h2->color = !empty($h2Style->title_color) ? "--nb-h2-color: {$h2Style->title_color};" : "";
            $params->customization->h2->space = "--nb-h2-padding: " . implode(" ", $h2Style->title_space) . ";";
            // array com as variaveis dos parametros para h2
            $h2Params = array($params->customization->h2->font, $params->customization->h2->alignment, $params->customization->h2->transform, $params->customization->h2->size, $params->customization->h2->color, $params->customization->h2->space, $params->customization->h2->sizeMobile);
            // junta todos os valores dos parametros dos textos em uma string
            $params->customization->variablesCss .= "\n";
            $params->customization->variablesCss .= implode("\n", $h2Params);
        }
        // pega o estilo setado na modal do h3
        $h3Style = json_decode($tmplParams->get('heading_h3'));
        if(!empty($h3Style)){
            // atribui esses valores para o objeto de configuracoes
            $params->customization->h3 = new StdClass;
            $params->customization->h3->font = "--nb-h3-font-family: " . NoBossUtilFonts::importNobossfontlist($h3Style->title_font, true) . ";";
            $params->customization->h3->alignment = "--nb-h3-align: {$h3Style->title_alignment};";
            $params->customization->h3->transform = "--nb-h3-transform: {$h3Style->title_transform};";
            $params->customization->h3->size = "";
            if(!empty($h3Style->title_size)){
                $fontSizeEm = $h3Style->title_size / 16;
                $params->customization->h3->size = "--nb-h3-font-size: {$h3Style->title_size}px;" . "\n" . "--nb-h3-font-size-em: {$fontSizeEm}em;";
            }
            $params->customization->h3->sizeMobile = "";
            if(!empty($h3Style->title_size_mobile)){
                $fontSizeEm = $h3Style->title_size_mobile / 16;
                $params->customization->h3->sizeMobile = "--nb-mobile-h3-font-size: {$h3Style->title_size_mobile}px;" . "\n" . "--nb-mobile-h3-font-size-em: {$fontSizeEm}em;";
            }
            $params->customization->h3->color = !empty($h3Style->title_color) ? "--nb-h3-color: {$h3Style->title_color};" : "";
            $params->customization->h3->space = "--nb-h3-padding: " . implode(" ", $h3Style->title_space) . ";";
            // array com as variaveis dos parametros para h3
            $h3Params = array($params->customization->h3->font, $params->customization->h3->alignment, $params->customization->h3->transform, $params->customization->h3->size, $params->customization->h3->color, $params->customization->h3->space, $params->customization->h3->sizeMobile);
            // junta todos os valores dos parametros dos textos em uma string
            $params->customization->variablesCss .= "\n";
            $params->customization->variablesCss .= implode("\n", $h3Params);
        }
        // pega o estilo setado na modal do h4
        $h4Style = json_decode($tmplParams->get('heading_h4'));
        if(!empty($h4Style)){
            // atribui esses valores para o objeto de configuracoes
            $params->customization->h4 = new StdClass;
            $params->customization->h4->font = "--nb-h4-font-family: " . NoBossUtilFonts::importNobossfontlist($h4Style->title_font, true) . ";";
            $params->customization->h4->alignment = "--nb-h4-align: {$h4Style->title_alignment};";
            $params->customization->h4->transform = "--nb-h4-transform: {$h4Style->title_transform};";
            $params->customization->h4->size = "";
            if(!empty($h4Style->title_size)){
                $fontSizeEm = $h4Style->title_size / 16;
                $params->customization->h4->size = "--nb-h4-font-size: {$h4Style->title_size}px;" . "\n" . "--nb-h4-font-size-em: {$fontSizeEm}em;";
            }
            $params->customization->h4->sizeMobile = "";
            if(!empty($h4Style->title_size_mobile)){
                $fontSizeEm = $h4Style->title_size_mobile / 16;
                $params->customization->h4->sizeMobile = "--nb-mobile-h4-font-size: {$h4Style->title_size_mobile}px;" . "\n" . "--nb-mobile-h4-font-size-em: {$fontSizeEm}em;";
            }
            $params->customization->h4->color = !empty($h4Style->title_color) ? "--nb-h4-color: {$h4Style->title_color};" : "";
            $params->customization->h4->space = "--nb-h4-padding: " . implode(" ", $h4Style->title_space) . ";";
            // array com as variaveis dos parametros para h4
            $h4Params = array($params->customization->h4->font, $params->customization->h4->alignment, $params->customization->h4->transform, $params->customization->h4->size, $params->customization->h4->color, $params->customization->h4->space, $params->customization->h4->sizeMobile);
            // junta todos os valores dos parametros dos textos em uma string
            $params->customization->variablesCss .= "\n";
            $params->customization->variablesCss .= implode("\n", $h4Params);
        }
        // pega o estilo setado na modal do h5
        $h5Style = json_decode($tmplParams->get('heading_h5'));
        if(!empty($h5Style)){
            // atribui esses valores para o objeto de configuracoes
            $params->customization->h5 = new StdClass;
            $params->customization->h5->font = "--nb-h5-font-family: " . NoBossUtilFonts::importNobossfontlist($h5Style->title_font, true) . ";";
            $params->customization->h5->alignment = "--nb-h5-align: {$h5Style->title_alignment};";
            $params->customization->h5->transform = "--nb-h5-transform: {$h5Style->title_transform};";
            $params->customization->h5->size = "";
            if(!empty($h5Style->title_size)){
                $fontSizeEm = $h5Style->title_size / 16;
                $params->customization->h5->size = "--nb-h5-font-size: {$h5Style->title_size}px;" . "\n" . "--nb-h5-font-size-em: {$fontSizeEm}em;";
            }
            $params->customization->h5->sizeMobile = "";
            if(!empty($h5Style->title_size_mobile)){
                $fontSizeEm = $h5Style->title_size_mobile / 16;
                $params->customization->h5->sizeMobile = "--nb-mobile-h5-font-size: {$h5Style->title_size_mobile}px;" . "\n" . "--nb-mobile-h5-font-size-em: {$fontSizeEm}em;";
            }
            $params->customization->h5->color = !empty($h5Style->title_color) ? "--nb-h5-color: {$h5Style->title_color};" : "";
            $params->customization->h5->space = "--nb-h5-padding: " . implode(" ", $h5Style->title_space) . ";";
            // array com as variaveis dos parametros para h5
            $h5Params = array($params->customization->h5->font, $params->customization->h5->alignment, $params->customization->h5->transform, $params->customization->h5->size, $params->customization->h5->color, $params->customization->h5->space, $params->customization->h5->sizeMobile);
            // junta todos os valores dos parametros dos textos em uma string
            $params->customization->variablesCss .= "\n";
            $params->customization->variablesCss .= implode("\n", $h5Params);

        }
        // pega o estilo setado na modal do h6
        $h6Style = json_decode($tmplParams->get('heading_h6'));
        if(!empty($h6Style)){
                       // atribui esses valores para o objeto de configuracoes
            $params->customization->h6 = new StdClass;
            $params->customization->h6->font = "--nb-h6-font-family: " . NoBossUtilFonts::importNobossfontlist($h6Style->title_font, true) . ";";
            $params->customization->h6->alignment = "--nb-h6-align: {$h6Style->title_alignment};";
            $params->customization->h6->transform = "--nb-h6-transform: {$h6Style->title_transform};";
            $params->customization->h6->size = "";
            if(!empty($h6Style->title_size)){
                $fontSizeEm = $h6Style->title_size / 16;
                $params->customization->h6->size = "--nb-h6-font-size: {$h6Style->title_size}px;" . "\n" . "--nb-h6-font-size-em: {$fontSizeEm}em;";
            }
            $params->customization->h6->sizeMobile = "";
            if(!empty($h6Style->title_size_mobile)){
                $fontSizeEm = $h6Style->title_size_mobile / 16;
                $params->customization->h6->sizeMobile = "--nb-mobile-h6-font-size: {$h6Style->title_size_mobile}px;" . "\n" . "--nb-mobile-h6-font-size-em: {$fontSizeEm}em;";
            }
            $params->customization->h6->color = !empty($h6Style->title_color) ? "--nb-h6-color: {$h6Style->title_color};" : "";
            $params->customization->h6->space = "--nb-h6-padding: " . implode(" ", $h6Style->title_space) . ";";
            // array com as variaveis dos parametros para h6
            $h6Params = array($params->customization->h6->font, $params->customization->h6->alignment, $params->customization->h6->transform, $params->customization->h6->size, $params->customization->h6->color, $params->customization->h6->space, $params->customization->h6->sizeMobile);
            // junta todos os valores dos parametros dos textos em uma string
            $params->customization->variablesCss .= "\n";
            $params->customization->variablesCss .= implode("\n", $h6Params);

        }
        // CSS e JS
        $params->customization->load_css_bootstrap = $tmplParams->get('load_css_bootstrap');
        $params->customization->css_bootstrap_version = $tmplParams->get('css_bootstrap_version', 'joomla');
        $params->customization->load_css_materialize = $tmplParams->get('load_css_materialize');
        $params->customization->css_materialize_version = $tmplParams->get('css_materialize_version', '1.0.0');
        $params->customization->load_js_polyfill = $tmplParams->get('load_js_polyfill');
        $params->customization->load_custom_css = $tmplParams->get('load_custom_css');
        $params->customization->load_css = $tmplParams->get('load_css');
        $params->customization->overwriting_css = $tmplParams->get('overwriting_css', '');
        $params->customization->load_js_jquery = $tmplParams->get('load_js_jquery');
        $params->customization->js_jquery_version = $tmplParams->get('js_jquery_version', 'joomla');
        $params->customization->load_js_bootstrap = $tmplParams->get('load_js_bootstrap');
        $params->customization->js_bootstrap_version = $tmplParams->get('js_bootstrap_version', 'joomla');
        $params->customization->load_js_materialize = $tmplParams->get('load_js_materialize');
        $params->customization->js_materialize_version = $tmplParams->get('js_materialize_version', '1.0.0');
        $params->customization->load_custom_js = $tmplParams->get('load_custom_js');
        $params->customization->overwriting_js = $tmplParams->get('overwriting_js', '');
        $params->customization->load_css_materialize = $tmplParams->get('load_css_materialize', '0');
        $params->customization->disable_jquery_joomla = $tmplParams->get('disable_jquery_joomla', '0');

        // configuracoes da aba 'layout'
        $params->layout = new StdClass;
        $params->layout->headerPosition = $tmplParams->get('header_position');
        $params->layout->afterHeader = $tmplParams->get('after_header_content');
        $params->layout->beforeFooter = $tmplParams->get('before_footer_content');
        $params->layout->footerPosition = $tmplParams->get('footer_position');
        // configuracoes da aba 'codigo personalizado'
        $params->customCode = new StdClass;
        $params->customCode->beforeHead = $tmplParams->get('before_head');
        $params->customCode->afterHead = $tmplParams->get('after_head');
        $params->customCode->beforeBody = $tmplParams->get('before_body');
        $params->customCode->afterBody = $tmplParams->get('after_body');
        // configuracoes da aba 'avancado'
        $params->advanced = new StdClass;
        // $params->advanced->developmentMode = $tmplParams->get('development_mode');
        $params->advanced->sharingImage = $tmplParams->get('sharing_image');
        $params->advanced->favicon = $tmplParams->get('favicon');
        $params->advanced->enableAnalytics = $tmplParams->get('enable_analytics');
        $params->advanced->trackingId = $tmplParams->get('tracking_id');
        $params->advanced->enableGeo = $tmplParams->get('enable_geo');
        $params->advanced->latitude = $tmplParams->get('latitude');
        $params->advanced->longitude = $tmplParams->get('longitude');
        $params->advanced->placeName = $tmplParams->get('placename');
        $params->advanced->region = $tmplParams->get('region');
        // retorna objeto completo com todas as configuracoes tratadas
        return $params;
    }

    /**
	 * Verifica se No Boss Library esta instalada no site e caso nao esteja, forca uma atualizacao e recarrega a pagina
     * 
     * OBS: essa acao eh necessaria para contornar problema em atualizacoes da library no processo do Joomla que as vezes mantem ela removida
	 *
	 * @return  void
	 */
    public static function checkLibraryInstallation(){
        // Library da No Boss nao localizada: inicia instalacao forcada da library
        if(!JFolder::exists(JPATH_LIBRARIES.'/noboss')) {
            try {
                // Adiciona diretorio de models do componente installer do Joomla
                JModelLegacy::addIncludePath(JPATH_ADMINISTRATOR . '/components/com_installer/models');
                // Instancia model de extensoes
                $modelInstaller = JModelLegacy::getInstance('install', 'InstallerModel');
                $input = JFactory::getApplication()->input;
                // Seta para utilizar metodo de instalacao via url
                $input->set('installtype', 'url');
                // Seta a url de instalacao da library
                $input->set('install_url', 'https://www.nobossextensions.com/en/installation/nobosslibrary/');
                // Executa metodo de instalacao
                $modelInstaller->install();
            } catch (Exception $e) {
                // Nao tem tratamento de erro pq o Joomla joga diversas vezes a falta de permissoes como erro sendo que ocorreu tudo certo
            }

            // Library foi instalada com sucesso
            if(JFolder::exists(JPATH_LIBRARIES.'/noboss')) {
                // Recarrega a pagina
                header("Refresh:0");
                exit;
            }
            else{
                return false;
            }
        }
        return true;
    }

    /**
	 * Funcao executada antes de qualquer acao de update do joomla
     * 
	 * @param   JUpdate       $update  An update definition
     * @param   JTableUpdate  $table   The update instance from the database
	 */
    public static function prepareUpdate($update, $table){
        jimport('noboss.util.installscript');

        // Token da licenca
        $token = str_replace('token=', '', $update->get('extra_query'));

        if (method_exists('NoBossUtilInstallscript','updateLicenseIsValid')){
            // Busca no servidor da No Boss se extensao possui permissao para update
            $return = NoBossUtilInstallscript::updateLicenseIsValid($token);
            
            // Token nao localizado
            if ($return == 'INVALID_TOKEN'){
                $msg = "<b>There are problems with the extension license:</b> <br /><br /> &bull; Your extension token was not found on the No Boss Extensions platform. <br /><br />";
                JFactory::getApplication()->enqueueMessage($msg, 'error');
                return false;
            }
            // Extensao nao possui suporte valido
            else if($return == 'INVALID'){
                $msg = "<b>License with expired update period:</b> <br /><br /> &bull; To update the extension, it is necessary to renew the license support period. <br /> &bull; You can renew the support time by accessing the tab called 'License' available within the edition of any extension registration. <br /><br />";
                JFactory::getApplication()->enqueueMessage($msg, 'error');
                return false;
            }
        }
    }
}


