<?php
/**
 * @package         No Boss Extensions
 * @subpackage      Template padrao
 * @author          No Boss Technology <contact@nobosstechnology.com>
 * @copyright       Copyright (C) 2021 No Boss Technology. All rights reserved.
 * @license         GNU Lesser General Public License version 3 or later; see <https://www.gnu.org/licenses/lgpl-3.0.en.html>
 */

defined ( '_JEXEC' ) or die ();

// carrega o helper do template
JLoader::register('NoBossNemesisTemplateHelper', __DIR__ . '/helper.php');

// Verifica se no boss library esta instalada: se ainda nao estiver, tenta instalar e se ainda nao der retorna false
if(!NoBossNemesisTemplateHelper::checkLibraryInstallation()){
    exit;
}

$app             = JFactory::getApplication();
$doc             = JFactory::getDocument();
$user            = JFactory::getUser();
$headData = $doc->getHeadData();
$this->direction = $doc->direction;

// Parametros do configuration
$config    = JFactory::getConfig();
// pega parametros do admin ja tratados
$params = NoBossNemesisTemplateHelper::getTemplateParams($this->params);

// Informacoes de idioma
$languageCurrent    = JFactory::getLanguage();
$tagLanguageCurrent = $languageCurrent->getTag();
$languages          = JLanguageHelper::getLanguages('lang_code');
$languageCurrent    = $languages[$tagLanguageCurrent];
$sefLanguageCurrent = $languageCurrent->sef;

?>
<!DOCTYPE html>
<html xmlns="http://www.w3.org/1999/xhtml" xmlns:og='http://ogp.me/ns#' xml:lang="<?php echo $this->language; ?>" lang="<?php echo $this->language; ?>" dir="<?php echo $this->direction; ?>">
<head>

    <?php
        $keywords = ( !empty($headData['metaTags']['standard']['keywords']) ) ? $headData['metaTags']['standard']['keywords'] : $config->get('MetaKeys');
        $description = $headData['description'];
        $siteName = $headData['title'];
        $domain = JUri::base();
        $creator = $config->get('MetaRights');
        $copyright = '© '.$app->get('fromname').' '.date('Y');
        $currentUrl = JURI::current();
        $latLng = !empty($params->advanced->latitude) && !empty($params->advanced->longitude) ? "{$params->advanced->latitude}, {$params->advanced->longitude}" : "";
        $placeName = !empty($params->advanced->placeName) ? $params->advanced->placeName : "";
        $region = !empty($params->advanced->region) ? $params->advanced->region : "";

        // Dados do menu atibo
        $activeMenu = $app->getMenu()->getActive();
        $activeMenuParams = $activeMenu->getParams($activeMenu->id);

        if(!empty($activeMenu)){
            $menuItemRobots = $activeMenuParams['robots'];
        }
        $configRobots = $config->get('robots');
        // pega a configuracao de robots do item de menu ou da configuracao global
        $robots = !empty($menuItemRobots) ? $menuItemRobots : $configRobots;
        $sharingImage = $params->advanced->sharingImage;
        $favIcon = $params->advanced->favicon;
        // imagem de compartilhamento, faz verificacao se eh uma imagem lozalicada no proprio site ou se eh de uma url externa
        if(!empty($sharingImage)){
            if (!filter_var($sharingImage, FILTER_VALIDATE_URL)) {
                $sharingImage = JURI::root() . $sharingImage;
            }
        }
        // favicon, faz verificacao se eh uma imagem lozalicada no proprio site ou se eh de uma url externa
        if(!empty($favIcon)){
            if (!filter_var($favIcon, FILTER_VALIDATE_URL)) {
                $favIcon = JURI::root() . $favIcon;
            }
        }
    ?>
    <?php // verifica se foi definido conteudo a ser inserido no inicio do head ?>
    <?php if(!empty($params->customCode->beforeHead)){
        echo $params->customCode->beforeHead;
    }?>
   
    <jdoc:include type="head" />

    <meta charset="UTF-8">
    <meta name="format-detection" content="telephone=no">
    <meta name="rating" content="general">
    <meta name="robots" content="<?php echo empty($robots) ? 'all' : $robots; ?>">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <?php // verifica se foi habilitado as metatags de localizacao no admin do template ?>
    <?php if($params->advanced->enableGeo){ ?>
        <meta name="ICBM" content="<?php echo $latLng; ?>">
        <meta name="geo.position" content="<?php echo $latLng; ?>">
        <meta name="geo.placename" content="<?php echo $placeName; ?>">
        <meta name="geo.region" content="<?php echo $region; ?>">
    <?php } ?>
    <meta name="DC.title" content="<?php echo $siteName;?>">
    <meta http-equiv="X-UA-Compatible" content="IE=EmulateIE7" />
    <meta http-equiv="X-UA-Compatible" content="IE=Edge" />
    <meta name="DC.creator " content="<?php echo $creator;?>">
    <meta name="DC.publisher " content="<?php echo $creator;?>">
    <meta name="DC.subject" lang="<?php echo $this->language; ?>" content="<?php echo $keywords;?>">
    <meta name="DC.identifier" scheme="DCTERMS.URI" content="<?php echo $domain;?>" />
    <meta name="DC.creator.address" content="<?php echo $this->language; ?>" />
    <meta name="Abstract" content="<?php echo $description;?>" />
    <meta name="author" content="<?php echo $creator;?>">
    <meta name="publisher" content="<?php echo $creator;?>">
    <meta name="owner" content="<?php echo $creator;?>">
    <meta name="copyright" content="<?php echo $copyright;?>">
    <meta property="og:title" content="<?php echo $siteName;?>">
    <meta property="og:site_name" content="<?php echo $creator;?>">
    <meta property="og:url" content="<?php echo $currentUrl;?>">
    <?php
    if(!$doc->getMetaData("og:type")) {
        $doc->setMetaData("og:type", "website");
    }
    ?>
    <meta property="og:locale" content="<?php echo str_replace('-','_',$this->language);?>">
    <meta property="og:description" content="<?php echo $description;?>"/>
    <meta name="twitter:title" content="<?php echo $siteName;?>">
    <meta name="twitter:card" content="summary">
    <meta name="twitter:site" content="<?php echo $domain;?>">
    <meta name="twitter:creator" content="<?php echo $creator;?>">
    <meta name="twitter:url" content="<?php echo $currentUrl;?>">
    <?php if(!$doc->getMetaData("twitter:description") && !empty($description)) { ?>
        <meta name="twitter:description" value="<?php echo $description;?>" />
    <?php } ?>
    <?php if(!empty($favIcon)){ ?>
        <link rel="shortcut icon" href="<?php echo $favIcon; ?>" type="image/x-icon"/>
    <?php } ?>
    <?php
    // Imagem de compartilhamento: caso não esteja de definido por um com e tenha sido setado uma imagem, seta a padrão
    if(!$doc->getMetaData("twitter:image") && !empty($sharingImage)) {
        $doc->setMetaData("twitter:image", $sharingImage);
        $doc->setMetaData('og:image', $sharingImage );
    }
    ?>

    <style type="text/css">
        :root{
            <?php echo $params->customization->variablesCss; ?>
        }
    </style>
    <?php // Adiciona suporte quando acesso for utilizando touch (mobile/tela touch) ?>
    <script>
        document.documentElement.className = document.documentElement.className.replace("no-js","js");
        document.documentElement.className += "ontouchstart" in document.documentElement ? " touch" : " no-touch";
    </script>

    <script type="text/javascript">var baseNameUrl = "<?php echo JUri::root(); ?>"</script>

    <?php // Armazena sef do idioma atual para concatenar na url dos iframes utilizados no processo de compra ?>
    <script type="text/javascript">
        var sefLanguage = "<?php echo $sefLanguageCurrent; ?>";
    </script>

    <?php
    // Carregar arquivo CSS Bootstrap
    if($params->customization->load_css_bootstrap){
        // Carrega versao do Joomla
        if($params->customization->css_bootstrap_version == 'joomla'){
            // Joomla 3
            if(version_compare(JVERSION, '4', '<')){
                // Carrega CSS Boostrap
                $doc->addStyleSheet($this->baseurl.'/media/jui/css/bootstrap.min.css', array('version' => 'auto', 'relative' => false));
            }
            // Joomla a partir do 4
            else{
                // Carrega css do bootstrap
                JHtml::_('bootstrap.loadCss', true);
            }            
        }
        // Carrega versao esclhida pelo usuario
        else{
            $doc->addStyleSheet("https://maxcdn.bootstrapcdn.com/bootstrap/{$params->customization->css_bootstrap_version}/css/bootstrap.min.css", array('version' => 'auto', 'relative' => false));
        }
    }
    // Carregar arquivo CSS Materialize
    if($params->customization->load_css_materialize){
        $doc->addStyleSheet("https://cdnjs.cloudflare.com/ajax/libs/materialize/{$params->customization->css_materialize_version}/css/materialize.min.css", array('version' => 'auto', 'relative' => false));
    }
    // CSS principal da extensao
    if($params->customization->load_css){
        $doc->addStyleSheet($this->baseurl . '/templates/' . $this->template . '/assets/stylesheets/css/style.min.css');
    }

    // Carregar arquivo customizado de CSS do template
    if(($params->customization->load_custom_css) && (JFile::exists(JPATH_ROOT . '/templates/nobossnemesis/assets/stylesheets/css/custom.css'))){
        $doc->addStyleSheet($this->baseurl . '/templates/nobossnemesis/assets/stylesheets/css/custom.css');
    } 
    // Carregar codigo personalizado de CSS
    if(!empty($params->customization->overwriting_css)){
        $doc->addStyleDeclaration($params->customization->overwriting_css);
    }
    
    // Carregar arquivo JS jQuery
    if($params->customization->load_js_jquery){
        // Carrega versao do Joomla
        if($params->customization->js_jquery_version == 'joomla'){
            // Carregar js do jquery
            JHtml::_('jquery.framework');
        }
        // Carrega versao esclhida pelo usuario
        else{
            $doc->addScript("https://ajax.googleapis.com/ajax/libs/jquery/{$params->customization->js_jquery_version}/jquery.min.js");
        }
    }
    // Setado para desabilitar jquery do Joomla
    if($params->customization->disable_jquery_joomla){
        unset($doc->_scripts[$this->baseurl.'/media/jui/js/jquery.min.js']);
    }
    // Carregar arquivo JS Bootstrap
    if($params->customization->load_js_bootstrap){
        // Carrega versao do Joomla
        if($params->customization->js_bootstrap_version == 'joomla'){
            // Carrega todos arquivos JS que compoem o bootstrap
            JHtml::_('bootstrap.framework');
        }
        // Carrega versao esclhida pelo usuario
        else{
            $doc->addScript("https://stackpath.bootstrapcdn.com/bootstrap/{$params->customization->js_bootstrap_version}/js/bootstrap.min.js");
        }
    }
    // Setado para desabilitar bootstrap do Joomla
    if($params->customization->disable_jquery_joomla){
        unset($doc->_scripts[$this->baseurl.'/media/jui/js/bootstrap.min.js']);
    }
    // Carregar arquivo JS Materialize
    if($params->customization->load_js_materialize){
        $doc->addScript("https://cdnjs.cloudflare.com/ajax/libs/materialize/{$params->customization->js_materialize_version}/js/materialize.min.js");
    }
    // Carregar arquivo CSS Polyfill
    if($params->customization->load_js_polyfill){
        $doc->addScript($this->baseurl . '/libraries/noboss/assets/util/js/min/cssvarpolyfill.min.js', array('version' => 'auto', 'relative' => false), array('async' => true, 'defer' => true));
    }
    // Carregar arquivo customizado de JS do template
    if(($params->customization->load_custom_js) && (JFile::exists(JPATH_ROOT . '/templates/nobossnemesis/assets/js/src/custom.js'))){
        $doc->addScript($this->baseurl . '/templates/nobossnemesis/assets/js/src/custom.js');
    }
    
    // Carregar codigo personalizado de JS
    if(!empty($params->customization->overwriting_js)){
        $doc->addScriptDeclaration($params->customization->overwriting_js);
    }
    
    // Conteudo a inserir no final do HEAD
    if(!empty($params->customCode->afterHead)){
        echo $params->customCode->afterHead;
    }
    ?>
</head>
<body class="nobossnemesis">

    <?php // verifica se foi definido posicao de modulo de topo e carrega o modulo ?>
    <?php if(!empty($params->layout->headerPosition)){ ?>
        <jdoc:include type="modules" name="<?php echo $params->layout->headerPosition; ?>" />
    <?php } ?>

    <?php // verifica se foi definido conteudo apos o header e carrega ele ?>
    <?php
        if(!empty($params->layout->afterHeader)){
            echo JHTML::_('content.prepare', $params->layout->afterHeader);
        }
    ?>

    <main role="main">
        <?php // verifica se foi definido conteudo a ser inserido antes do body ?>
        <?php if(!empty($params->customCode->beforeBody)){
            echo $params->customCode->beforeBody;
        }?>
        <?php // Componente ?>
        <jdoc:include type="component" />


        <?php // verifica se foi definido conteudo antes do footer e carrega ele ?>
        <?php
            if(!empty($params->layout->beforeFooter)){
                echo JHTML::_('content.prepare', $params->layout->beforeFooter);
            }
        ?>
    </main>
    <?php // carrega o footer caso uma posicao de modulo tenha sido definida ?>
    <?php if(!empty($params->layout->footerPosition)){ ?>
        <jdoc:include type="modules" name="<?php echo $params->layout->footerPosition; ?>" />
    <?php } ?>

    <?php // verifica se o google analytics deve ser habilitado ?>
    <?php if($params->advanced->enableAnalytics){ ?>
        <!-- Global site tag (gtag.js) - Google Analytics -->
        <script async src="https://www.googletagmanager.com/gtag/js?id=<?php echo $params->advanced->trackingId; ?>"></script>
        <script>
            window.dataLayer = window.dataLayer || [];
            function gtag(){dataLayer.push(arguments);}
            gtag('js', new Date());
            gtag("config", "<?php echo $params->advanced->trackingId; ?>");
        </script>
    <?php } ?>

    <?php // verifica se foi definido conteudo a ser inserido no final do body ?>
    <?php if(!empty($params->customCode->afterBody)){
        echo $params->customCode->afterBody;
    }?>

    <?php
    // Url do theme preview (utilizado somente em site demo)
    if ($nbUrlThemePreview = $config->get('nb_url_theme_preview')){
        $doc->addScriptDeclaration('jQuery.get( "'.$nbUrlThemePreview.'&lang='.$sefLanguageCurrent.'&url_request='.JURI::root().'", function( data ) { jQuery("body").append(data); });');
    }
    ?>
   
</body>
</html>
